# Changelog

## 1.1.1 (2024-01-07)

### Fix

- **check_results**: fix | is not supported in py3.8 and py3.9 bug

### Refactor

- **generate_color**: fix var name 'l' bug

## 1.1.0 (2024-01-07)

### Feat

- **version**: add version feat

### Fix

- **length**: fix length bug of check_results
- **noop**: fix noop bug

## 1.0.3 (2024-01-07)
